# pylint: disable=too-many-lines
"""The horizontal commands module.

These commands are used in the following models:
DPO2K, DPO2KB, MSO2K, MSO2KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - HORizontal:ACQLENGTH?
    - HORizontal:DELay:MODe {OFF|ON|<NR1>}
    - HORizontal:DELay:MODe?
    - HORizontal:DELay:POSition
    - HORizontal:DELay:POSition?
    - HORizontal:DELay:TIMe <NR3>
    - HORizontal:DELay:TIMe?
    - HORizontal:DIGital:RECOrdlength:MAGnivu?
    - HORizontal:DIGital:RECOrdlength:MAIN?
    - HORizontal:DIGital:SAMPLERate:MAGnivu?
    - HORizontal:DIGital:SAMPLERate:MAIN?
    - HORizontal:MAIn:SAMPLERate
    - HORizontal:MAIn:SCAle
    - HORizontal:MAIn:SCAle?
    - HORizontal:MAIn:UNIts:STRing?
    - HORizontal:MAIn:UNIts?
    - HORizontal:MAIn?
    - HORizontal:POSition <NR3>
    - HORizontal:POSition?
    - HORizontal:PREViewstate?
    - HORizontal:RECOrdlength <NR1>
    - HORizontal:RECOrdlength?
    - HORizontal:RESOlution <NR1>
    - HORizontal:RESOlution?
    - HORizontal:SAMPLERate?
    - HORizontal:SCAle <NR3>
    - HORizontal:SCAle?
    - HORizontal:TRIGger:POSition
    - HORizontal:TRIGger:POSition?
    - HORizontal?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class HorizontalTriggerPosition(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``HORizontal:TRIGger:POSition`` command.

    **Description:**
        - Sets the horizontal position when delay mode is OFF. It is similar to
          ``HORIZONTAL:POSITION``.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:TRIGger:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:TRIGger:POSition?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``HORizontal:TRIGger:POSition`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:TRIGger:POSition
        - HORizontal:TRIGger:POSition?
    """


class HorizontalTrigger(SCPICmdRead):
    """The ``HORizontal:TRIGger`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:TRIGger?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:TRIGger?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.position``: The ``HORizontal:TRIGger:POSition`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._position = HorizontalTriggerPosition(device, f"{self._cmd_syntax}:POSition")

    @property
    def position(self) -> HorizontalTriggerPosition:
        """Return the ``HORizontal:TRIGger:POSition`` command.

        **Description:**
            - Sets the horizontal position when delay mode is OFF. It is similar to
              ``HORIZONTAL:POSITION``.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:TRIGger:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:TRIGger:POSition?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``HORizontal:TRIGger:POSition`` command.

        **SCPI Syntax:**

        ::

            - HORizontal:TRIGger:POSition
            - HORizontal:TRIGger:POSition?
        """
        return self._position


class HorizontalScale(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:SCAle`` command.

    **Description:**
        - This command sets or queries the horizontal scale.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:SCAle?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:SCAle value`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:SCAle <NR3>
        - HORizontal:SCAle?

    **Info:**
        - ``<NR3>`` is the horizontal scale in time per division.
    """


class HorizontalSamplerate(SCPICmdRead):
    """The ``HORizontal:SAMPLERate`` command.

    **Description:**
        - The command form is ignored. The query returns the sample rate for analog channels in
          samples per second.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:SAMPLERate?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:SAMPLERate?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:SAMPLERate?
    """


class HorizontalResolution(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:RESOlution`` command.

    **Description:**
        - Sets or returns the horizontal record length of acquired waveforms. The sample rate is
          automatically adjusted at the same time to maintain a constant time per division. The
          query form of this command returns the current horizontal record length.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:RESOlution?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:RESOlution?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:RESOlution value`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:RESOlution <NR1>
        - HORizontal:RESOlution?

    **Info:**
        - ``<NR1>`` represents the supported values for horizontal record lengths.
    """


class HorizontalRecordlength(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:RECOrdlength`` command.

    **Description:**
        - This command sets or queries the horizontal record length. To change the record length the
          Horizontal Mode must be set to Manual.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:RECOrdlength?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:RECOrdlength?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:RECOrdlength value``
          command.

    **SCPI Syntax:**

    ::

        - HORizontal:RECOrdlength <NR1>
        - HORizontal:RECOrdlength?

    **Info:**
        - ``<NR1>`` is the horizontal record length.
    """


class HorizontalPreviewstate(SCPICmdRead):
    """The ``HORizontal:PREViewstate`` command.

    **Description:**
        - This query returns the display system preview state.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:PREViewstate?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:PREViewstate?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:PREViewstate?
    """


class HorizontalPosition(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:POSition`` command.

    **Description:**
        - This command sets or queries the horizontal position as a percent of screen width. When
          Horizontal Delay Mode is turned off, this command is equivalent to adjusting the
          HORIZONTAL POSITION knob on the front panel. When Horizontal Delay Mode is turned on, the
          horizontal position is forced to 50%.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:POSition?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:POSition value`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:POSition <NR3>
        - HORizontal:POSition?

    **Info:**
        - ``<NR3>`` is from 0 to ≈100 and is the position of the trigger point on the screen (0 =
          left edge, 100 = right edge).
    """


class HorizontalMainUnitsString(SCPICmdRead):
    """The ``HORizontal:MAIn:UNIts:STRing`` command.

    **Description:**
        - Returns the units string for the horizontal time base.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:MAIn:UNIts:STRing?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:UNIts:STRing?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:MAIn:UNIts:STRing?
    """


class HorizontalMainUnits(SCPICmdRead):
    """The ``HORizontal:MAIn:UNIts`` command.

    **Description:**
        - Returns the units string for the horizontal time base.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:MAIn:UNIts?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:UNIts?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:MAIn:UNIts?

    Properties:
        - ``.string``: The ``HORizontal:MAIn:UNIts:STRing`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._string = HorizontalMainUnitsString(device, f"{self._cmd_syntax}:STRing")

    @property
    def string(self) -> HorizontalMainUnitsString:
        """Return the ``HORizontal:MAIn:UNIts:STRing`` command.

        **Description:**
            - Returns the units string for the horizontal time base.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:MAIn:UNIts:STRing?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:UNIts:STRing?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:MAIn:UNIts:STRing?
        """
        return self._string


class HorizontalMainScale(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``HORizontal:MAIn:SCAle`` command.

    **Description:**
        - Sets or returns the main horizontal scale. The specified scale value is rounded to a valid
          scale setting.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:MAIn:SCAle?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:SCAle?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``HORizontal:MAIn:SCAle`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:MAIn:SCAle
        - HORizontal:MAIn:SCAle?

    **Info:**
        - ``<NR3>`` is the time per division. The range is from 400 ps (1 ns) through 1000 s,
          depending on the record length.
    """


class HorizontalMainSamplerate(SCPICmdWriteNoArguments):
    """The ``HORizontal:MAIn:SAMPLERate`` command.

    **Description:**
        - Sets or returns the current horizontal sample rate.

    **Usage:**
        - Using the ``.write()`` method will send the ``HORizontal:MAIn:SAMPLERate`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:MAIn:SAMPLERate

    **Info:**
        - ``<NR3>`` specifies the sample rate in seconds.
    """


class HorizontalMain(SCPICmdRead):
    """The ``HORizontal:MAIn`` command.

    **Description:**
        - This query-only command returns the time per division of the time base. This command is
          equivalent to selecting Position/Scale from the Horiz/Acq menu.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:MAIn?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:MAIn?

    Properties:
        - ``.samplerate``: The ``HORizontal:MAIn:SAMPLERate`` command.
        - ``.units``: The ``HORizontal:MAIn:UNIts`` command.
        - ``.scale``: The ``HORizontal:MAIn:SCAle`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._samplerate = HorizontalMainSamplerate(device, f"{self._cmd_syntax}:SAMPLERate")
        self._units = HorizontalMainUnits(device, f"{self._cmd_syntax}:UNIts")
        self._scale = HorizontalMainScale(device, f"{self._cmd_syntax}:SCAle")

    @property
    def samplerate(self) -> HorizontalMainSamplerate:
        """Return the ``HORizontal:MAIn:SAMPLERate`` command.

        **Description:**
            - Sets or returns the current horizontal sample rate.

        **Usage:**
            - Using the ``.write()`` method will send the ``HORizontal:MAIn:SAMPLERate`` command.

        **SCPI Syntax:**

        ::

            - HORizontal:MAIn:SAMPLERate

        **Info:**
            - ``<NR3>`` specifies the sample rate in seconds.
        """
        return self._samplerate

    @property
    def units(self) -> HorizontalMainUnits:
        """Return the ``HORizontal:MAIn:UNIts`` command.

        **Description:**
            - Returns the units string for the horizontal time base.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:MAIn:UNIts?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:UNIts?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:MAIn:UNIts?

        Sub-properties:
            - ``.string``: The ``HORizontal:MAIn:UNIts:STRing`` command.
        """
        return self._units

    @property
    def scale(self) -> HorizontalMainScale:
        """Return the ``HORizontal:MAIn:SCAle`` command.

        **Description:**
            - Sets or returns the main horizontal scale. The specified scale value is rounded to a
              valid scale setting.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:MAIn:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn:SCAle?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``HORizontal:MAIn:SCAle`` command.

        **SCPI Syntax:**

        ::

            - HORizontal:MAIn:SCAle
            - HORizontal:MAIn:SCAle?

        **Info:**
            - ``<NR3>`` is the time per division. The range is from 400 ps (1 ns) through 1000 s,
              depending on the record length.
        """
        return self._scale


class HorizontalDigitalSamplerateMain(SCPICmdRead):
    """The ``HORizontal:DIGital:SAMPLERate:MAIN`` command.

    **Description:**
        - Returns the sample rate of the main digital acquisition.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate:MAIN?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital:SAMPLERate:MAIN?``
          query and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:DIGital:SAMPLERate:MAIN?
    """


class HorizontalDigitalSamplerateMagnivu(SCPICmdRead):
    """The ``HORizontal:DIGital:SAMPLERate:MAGnivu`` command.

    **Description:**
        - Returns the sample rate of the MagniVu digital acquisition.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate:MAGnivu?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``HORizontal:DIGital:SAMPLERate:MAGnivu?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:DIGital:SAMPLERate:MAGnivu?
    """


class HorizontalDigitalSamplerate(SCPICmdRead):
    """The ``HORizontal:DIGital:SAMPLERate`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital:SAMPLERate?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.magnivu``: The ``HORizontal:DIGital:SAMPLERate:MAGnivu`` command.
        - ``.main``: The ``HORizontal:DIGital:SAMPLERate:MAIN`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._magnivu = HorizontalDigitalSamplerateMagnivu(device, f"{self._cmd_syntax}:MAGnivu")
        self._main = HorizontalDigitalSamplerateMain(device, f"{self._cmd_syntax}:MAIN")

    @property
    def magnivu(self) -> HorizontalDigitalSamplerateMagnivu:
        """Return the ``HORizontal:DIGital:SAMPLERate:MAGnivu`` command.

        **Description:**
            - Returns the sample rate of the MagniVu digital acquisition.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate:MAGnivu?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``HORizontal:DIGital:SAMPLERate:MAGnivu?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:DIGital:SAMPLERate:MAGnivu?
        """
        return self._magnivu

    @property
    def main(self) -> HorizontalDigitalSamplerateMain:
        """Return the ``HORizontal:DIGital:SAMPLERate:MAIN`` command.

        **Description:**
            - Returns the sample rate of the main digital acquisition.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate:MAIN?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``HORizontal:DIGital:SAMPLERate:MAIN?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:DIGital:SAMPLERate:MAIN?
        """
        return self._main


class HorizontalDigitalRecordlengthMain(SCPICmdRead):
    """The ``HORizontal:DIGital:RECOrdlength:MAIN`` command.

    **Description:**
        - Returns the record length of the main digital acquisition.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:RECOrdlength:MAIN?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``HORizontal:DIGital:RECOrdlength:MAIN?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:DIGital:RECOrdlength:MAIN?
    """


class HorizontalDigitalRecordlengthMagnivu(SCPICmdRead):
    """The ``HORizontal:DIGital:RECOrdlength:MAGnivu`` command.

    **Description:**
        - Returns the record length of the MagniVu digital acquisition.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:RECOrdlength:MAGnivu?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``HORizontal:DIGital:RECOrdlength:MAGnivu?`` query and raise an AssertionError if the
          returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:DIGital:RECOrdlength:MAGnivu?
    """


class HorizontalDigitalRecordlength(SCPICmdRead):
    """The ``HORizontal:DIGital:RECOrdlength`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital:RECOrdlength?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital:RECOrdlength?``
          query and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.magnivu``: The ``HORizontal:DIGital:RECOrdlength:MAGnivu`` command.
        - ``.main``: The ``HORizontal:DIGital:RECOrdlength:MAIN`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._magnivu = HorizontalDigitalRecordlengthMagnivu(device, f"{self._cmd_syntax}:MAGnivu")
        self._main = HorizontalDigitalRecordlengthMain(device, f"{self._cmd_syntax}:MAIN")

    @property
    def magnivu(self) -> HorizontalDigitalRecordlengthMagnivu:
        """Return the ``HORizontal:DIGital:RECOrdlength:MAGnivu`` command.

        **Description:**
            - Returns the record length of the MagniVu digital acquisition.

        **Usage:**
            - Using the ``.query()`` method will send the
              ``HORizontal:DIGital:RECOrdlength:MAGnivu?`` query.
            - Using the ``.verify(value)`` method will send the
              ``HORizontal:DIGital:RECOrdlength:MAGnivu?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:DIGital:RECOrdlength:MAGnivu?
        """
        return self._magnivu

    @property
    def main(self) -> HorizontalDigitalRecordlengthMain:
        """Return the ``HORizontal:DIGital:RECOrdlength:MAIN`` command.

        **Description:**
            - Returns the record length of the main digital acquisition.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital:RECOrdlength:MAIN?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``HORizontal:DIGital:RECOrdlength:MAIN?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:DIGital:RECOrdlength:MAIN?
        """
        return self._main


class HorizontalDigital(SCPICmdRead):
    """The ``HORizontal:DIGital`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DIGital?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.recordlength``: The ``HORizontal:DIGital:RECOrdlength`` command tree.
        - ``.samplerate``: The ``HORizontal:DIGital:SAMPLERate`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._recordlength = HorizontalDigitalRecordlength(
            device, f"{self._cmd_syntax}:RECOrdlength"
        )
        self._samplerate = HorizontalDigitalSamplerate(device, f"{self._cmd_syntax}:SAMPLERate")

    @property
    def recordlength(self) -> HorizontalDigitalRecordlength:
        """Return the ``HORizontal:DIGital:RECOrdlength`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital:RECOrdlength?``
              query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital:RECOrdlength?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.magnivu``: The ``HORizontal:DIGital:RECOrdlength:MAGnivu`` command.
            - ``.main``: The ``HORizontal:DIGital:RECOrdlength:MAIN`` command.
        """
        return self._recordlength

    @property
    def samplerate(self) -> HorizontalDigitalSamplerate:
        """Return the ``HORizontal:DIGital:SAMPLERate`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital:SAMPLERate?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital:SAMPLERate?``
              query and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.magnivu``: The ``HORizontal:DIGital:SAMPLERate:MAGnivu`` command.
            - ``.main``: The ``HORizontal:DIGital:SAMPLERate:MAIN`` command.
        """
        return self._samplerate


class HorizontalDelayTime(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:DELay:TIMe`` command.

    **Description:**
        - This command sets or queries the horizontal delay time that is used when delay mode is on.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DELay:TIMe?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:TIMe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:DELay:TIMe value`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:DELay:TIMe <NR3>
        - HORizontal:DELay:TIMe?

    **Info:**
        - ``NR3`` is the delay in seconds.
    """


class HorizontalDelayPosition(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``HORizontal:DELay:POSition`` command.

    **Description:**
        - Sets or returns the horizontal position.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DELay:POSition?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:POSition?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``HORizontal:DELay:POSition`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:DELay:POSition
        - HORizontal:DELay:POSition?
    """


class HorizontalDelayMode(SCPICmdWrite, SCPICmdRead):
    """The ``HORizontal:DELay:MODe`` command.

    **Description:**
        - This command sets or queries the horizontal delay mode.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DELay:MODe?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:MODe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``HORizontal:DELay:MODe value`` command.

    **SCPI Syntax:**

    ::

        - HORizontal:DELay:MODe {OFF|ON|<NR1>}
        - HORizontal:DELay:MODe?

    **Info:**
        - ``OFF`` sets the Horizontal Delay Mode to off. This causes the ``HORizontal:POSition``
          command to operate like the HORIZONTAL POSITION knob on the front panel.
        - ``ON`` sets the Horizontal Delay Mode to on. This causes the ``HORizontal:DELay:TIMe``
          command to operate like the HORIZONTAL POSITION knob on the front panel.
        - ``<NR1>`` = 0 sets the Horizontal Delay Mode to off; any other value sets this mode to on.
    """


class HorizontalDelay(SCPICmdRead):
    """The ``HORizontal:DELay`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:DELay?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:DELay?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.mode``: The ``HORizontal:DELay:MODe`` command.
        - ``.position``: The ``HORizontal:DELay:POSition`` command.
        - ``.time``: The ``HORizontal:DELay:TIMe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._mode = HorizontalDelayMode(device, f"{self._cmd_syntax}:MODe")
        self._position = HorizontalDelayPosition(device, f"{self._cmd_syntax}:POSition")
        self._time = HorizontalDelayTime(device, f"{self._cmd_syntax}:TIMe")

    @property
    def mode(self) -> HorizontalDelayMode:
        """Return the ``HORizontal:DELay:MODe`` command.

        **Description:**
            - This command sets or queries the horizontal delay mode.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DELay:MODe?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:MODe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:DELay:MODe value``
              command.

        **SCPI Syntax:**

        ::

            - HORizontal:DELay:MODe {OFF|ON|<NR1>}
            - HORizontal:DELay:MODe?

        **Info:**
            - ``OFF`` sets the Horizontal Delay Mode to off. This causes the ``HORizontal:POSition``
              command to operate like the HORIZONTAL POSITION knob on the front panel.
            - ``ON`` sets the Horizontal Delay Mode to on. This causes the ``HORizontal:DELay:TIMe``
              command to operate like the HORIZONTAL POSITION knob on the front panel.
            - ``<NR1>`` = 0 sets the Horizontal Delay Mode to off; any other value sets this mode to
              on.
        """
        return self._mode

    @property
    def position(self) -> HorizontalDelayPosition:
        """Return the ``HORizontal:DELay:POSition`` command.

        **Description:**
            - Sets or returns the horizontal position.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DELay:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:POSition?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``HORizontal:DELay:POSition`` command.

        **SCPI Syntax:**

        ::

            - HORizontal:DELay:POSition
            - HORizontal:DELay:POSition?
        """
        return self._position

    @property
    def time(self) -> HorizontalDelayTime:
        """Return the ``HORizontal:DELay:TIMe`` command.

        **Description:**
            - This command sets or queries the horizontal delay time that is used when delay mode is
              on.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DELay:TIMe?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DELay:TIMe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:DELay:TIMe value``
              command.

        **SCPI Syntax:**

        ::

            - HORizontal:DELay:TIMe <NR3>
            - HORizontal:DELay:TIMe?

        **Info:**
            - ``NR3`` is the delay in seconds.
        """
        return self._time


class HorizontalAcqlength(SCPICmdRead):
    """The ``HORizontal:ACQLENGTH`` command.

    **Description:**
        - This query returns the record length.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal:ACQLENGTH?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal:ACQLENGTH?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal:ACQLENGTH?
    """


#  pylint: disable=too-many-instance-attributes
class Horizontal(SCPICmdRead):
    """The ``HORizontal`` command.

    **Description:**
        - Queries the current horizontal settings.

    **Usage:**
        - Using the ``.query()`` method will send the ``HORizontal?`` query.
        - Using the ``.verify(value)`` method will send the ``HORizontal?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - HORizontal?

    Properties:
        - ``.acqlength``: The ``HORizontal:ACQLENGTH`` command.
        - ``.delay``: The ``HORizontal:DELay`` command tree.
        - ``.digital``: The ``HORizontal:DIGital`` command tree.
        - ``.main``: The ``HORizontal:MAIn`` command.
        - ``.position``: The ``HORizontal:POSition`` command.
        - ``.previewstate``: The ``HORizontal:PREViewstate`` command.
        - ``.recordlength``: The ``HORizontal:RECOrdlength`` command.
        - ``.resolution``: The ``HORizontal:RESOlution`` command.
        - ``.samplerate``: The ``HORizontal:SAMPLERate`` command.
        - ``.scale``: The ``HORizontal:SCAle`` command.
        - ``.trigger``: The ``HORizontal:TRIGger`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "HORizontal") -> None:
        super().__init__(device, cmd_syntax)
        self._acqlength = HorizontalAcqlength(device, f"{self._cmd_syntax}:ACQLENGTH")
        self._delay = HorizontalDelay(device, f"{self._cmd_syntax}:DELay")
        self._digital = HorizontalDigital(device, f"{self._cmd_syntax}:DIGital")
        self._position = HorizontalPosition(device, f"{self._cmd_syntax}:POSition")
        self._previewstate = HorizontalPreviewstate(device, f"{self._cmd_syntax}:PREViewstate")
        self._recordlength = HorizontalRecordlength(device, f"{self._cmd_syntax}:RECOrdlength")
        self._resolution = HorizontalResolution(device, f"{self._cmd_syntax}:RESOlution")
        self._samplerate = HorizontalSamplerate(device, f"{self._cmd_syntax}:SAMPLERate")
        self._scale = HorizontalScale(device, f"{self._cmd_syntax}:SCAle")
        self._trigger = HorizontalTrigger(device, f"{self._cmd_syntax}:TRIGger")
        self._main = HorizontalMain(device, f"{self._cmd_syntax}:MAIn")

    @property
    def acqlength(self) -> HorizontalAcqlength:
        """Return the ``HORizontal:ACQLENGTH`` command.

        **Description:**
            - This query returns the record length.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:ACQLENGTH?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:ACQLENGTH?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:ACQLENGTH?
        """
        return self._acqlength

    @property
    def delay(self) -> HorizontalDelay:
        """Return the ``HORizontal:DELay`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DELay?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DELay?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.mode``: The ``HORizontal:DELay:MODe`` command.
            - ``.position``: The ``HORizontal:DELay:POSition`` command.
            - ``.time``: The ``HORizontal:DELay:TIMe`` command.
        """
        return self._delay

    @property
    def digital(self) -> HorizontalDigital:
        """Return the ``HORizontal:DIGital`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:DIGital?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:DIGital?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.recordlength``: The ``HORizontal:DIGital:RECOrdlength`` command tree.
            - ``.samplerate``: The ``HORizontal:DIGital:SAMPLERate`` command tree.
        """
        return self._digital

    @property
    def position(self) -> HorizontalPosition:
        """Return the ``HORizontal:POSition`` command.

        **Description:**
            - This command sets or queries the horizontal position as a percent of screen width.
              When Horizontal Delay Mode is turned off, this command is equivalent to adjusting the
              HORIZONTAL POSITION knob on the front panel. When Horizontal Delay Mode is turned on,
              the horizontal position is forced to 50%.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:POSition?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:POSition?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:POSition value``
              command.

        **SCPI Syntax:**

        ::

            - HORizontal:POSition <NR3>
            - HORizontal:POSition?

        **Info:**
            - ``<NR3>`` is from 0 to ≈100 and is the position of the trigger point on the screen (0
              = left edge, 100 = right edge).
        """
        return self._position

    @property
    def previewstate(self) -> HorizontalPreviewstate:
        """Return the ``HORizontal:PREViewstate`` command.

        **Description:**
            - This query returns the display system preview state.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:PREViewstate?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:PREViewstate?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:PREViewstate?
        """
        return self._previewstate

    @property
    def recordlength(self) -> HorizontalRecordlength:
        """Return the ``HORizontal:RECOrdlength`` command.

        **Description:**
            - This command sets or queries the horizontal record length. To change the record length
              the Horizontal Mode must be set to Manual.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:RECOrdlength?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:RECOrdlength?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:RECOrdlength value``
              command.

        **SCPI Syntax:**

        ::

            - HORizontal:RECOrdlength <NR1>
            - HORizontal:RECOrdlength?

        **Info:**
            - ``<NR1>`` is the horizontal record length.
        """
        return self._recordlength

    @property
    def resolution(self) -> HorizontalResolution:
        """Return the ``HORizontal:RESOlution`` command.

        **Description:**
            - Sets or returns the horizontal record length of acquired waveforms. The sample rate is
              automatically adjusted at the same time to maintain a constant time per division. The
              query form of this command returns the current horizontal record length.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:RESOlution?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:RESOlution?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:RESOlution value``
              command.

        **SCPI Syntax:**

        ::

            - HORizontal:RESOlution <NR1>
            - HORizontal:RESOlution?

        **Info:**
            - ``<NR1>`` represents the supported values for horizontal record lengths.
        """
        return self._resolution

    @property
    def samplerate(self) -> HorizontalSamplerate:
        """Return the ``HORizontal:SAMPLERate`` command.

        **Description:**
            - The command form is ignored. The query returns the sample rate for analog channels in
              samples per second.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:SAMPLERate?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:SAMPLERate?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:SAMPLERate?
        """
        return self._samplerate

    @property
    def scale(self) -> HorizontalScale:
        """Return the ``HORizontal:SCAle`` command.

        **Description:**
            - This command sets or queries the horizontal scale.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:SCAle?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:SCAle?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``HORizontal:SCAle value`` command.

        **SCPI Syntax:**

        ::

            - HORizontal:SCAle <NR3>
            - HORizontal:SCAle?

        **Info:**
            - ``<NR3>`` is the horizontal scale in time per division.
        """
        return self._scale

    @property
    def trigger(self) -> HorizontalTrigger:
        """Return the ``HORizontal:TRIGger`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:TRIGger?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:TRIGger?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.position``: The ``HORizontal:TRIGger:POSition`` command.
        """
        return self._trigger

    @property
    def main(self) -> HorizontalMain:
        """Return the ``HORizontal:MAIn`` command.

        **Description:**
            - This query-only command returns the time per division of the time base. This command
              is equivalent to selecting Position/Scale from the Horiz/Acq menu.

        **Usage:**
            - Using the ``.query()`` method will send the ``HORizontal:MAIn?`` query.
            - Using the ``.verify(value)`` method will send the ``HORizontal:MAIn?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - HORizontal:MAIn?

        Sub-properties:
            - ``.samplerate``: The ``HORizontal:MAIn:SAMPLERate`` command.
            - ``.units``: The ``HORizontal:MAIn:UNIts`` command.
            - ``.scale``: The ``HORizontal:MAIn:SCAle`` command.
        """
        return self._main



"""The output commands module.

These commands are used in the following models:
AWG5K, AWG5KC, AWG7K, AWG7KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - OUTPut[n]:FILTer:LPASs:FREQuency {<NR3>|INFinity}
    - OUTPut[n]:FILTer:LPASs:FREQuency?
    - OUTPut[n]:STATe <output_state>
    - OUTPut[n]:STATe?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, ValidatedDynamicNumberCmd

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class OutputItemState(SCPICmdWrite, SCPICmdRead):
    """The ``OUTPut[n]:STATe`` command.

    **Description:**
        - This command and query sets or returns the output state of the arbitrary waveform
          generator. Setting the output state of a channel to ON will switch on its analog output
          signal and marker.

    **Usage:**
        - Using the ``.query()`` method will send the ``OUTPut[n]:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``OUTPut[n]:STATe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``OUTPut[n]:STATe value`` command.

    **SCPI Syntax:**

    ::

        - OUTPut[n]:STATe <output_state>
        - OUTPut[n]:STATe?

    **Info:**
        - ``<output_state>`` ::=<Boolean>.
        - ``0`` sets the channel output to False (OFF).
        - ``1`` sets the channel output to True (ON).
    """


class OutputItemFilterLpassFrequency(SCPICmdWrite, SCPICmdRead):
    """The ``OUTPut[n]:FILTer:LPASs:FREQuency`` command.

    **Description:**
        - This command and query sets or returns the low-pass filter frequency of the filter.
          INFinity is same as Through (no filter). This command is not available on instruments with
          option 02 or option 06.

    **Usage:**
        - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer:LPASs:FREQuency?`` query.
        - Using the ``.verify(value)`` method will send the ``OUTPut[n]:FILTer:LPASs:FREQuency?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``OUTPut[n]:FILTer:LPASs:FREQuency value`` command.

    **SCPI Syntax:**

    ::

        - OUTPut[n]:FILTer:LPASs:FREQuency {<NR3>|INFinity}
        - OUTPut[n]:FILTer:LPASs:FREQuency?

    **Info:**
        - ``<NR3>``
    """


class OutputItemFilterLpass(SCPICmdRead):
    """The ``OUTPut[n]:FILTer:LPASs`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer:LPASs?`` query.
        - Using the ``.verify(value)`` method will send the ``OUTPut[n]:FILTer:LPASs?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.frequency``: The ``OUTPut[n]:FILTer:LPASs:FREQuency`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._frequency = OutputItemFilterLpassFrequency(device, f"{self._cmd_syntax}:FREQuency")

    @property
    def frequency(self) -> OutputItemFilterLpassFrequency:
        """Return the ``OUTPut[n]:FILTer:LPASs:FREQuency`` command.

        **Description:**
            - This command and query sets or returns the low-pass filter frequency of the filter.
              INFinity is same as Through (no filter). This command is not available on instruments
              with option 02 or option 06.

        **Usage:**
            - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer:LPASs:FREQuency?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``OUTPut[n]:FILTer:LPASs:FREQuency?`` query and raise an AssertionError if the
              returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``OUTPut[n]:FILTer:LPASs:FREQuency value`` command.

        **SCPI Syntax:**

        ::

            - OUTPut[n]:FILTer:LPASs:FREQuency {<NR3>|INFinity}
            - OUTPut[n]:FILTer:LPASs:FREQuency?

        **Info:**
            - ``<NR3>``
        """
        return self._frequency


class OutputItemFilter(SCPICmdRead):
    """The ``OUTPut[n]:FILTer`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer?`` query.
        - Using the ``.verify(value)`` method will send the ``OUTPut[n]:FILTer?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.lpass``: The ``OUTPut[n]:FILTer:LPASs`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._lpass = OutputItemFilterLpass(device, f"{self._cmd_syntax}:LPASs")

    @property
    def lpass(self) -> OutputItemFilterLpass:
        """Return the ``OUTPut[n]:FILTer:LPASs`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer:LPASs?`` query.
            - Using the ``.verify(value)`` method will send the ``OUTPut[n]:FILTer:LPASs?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.frequency``: The ``OUTPut[n]:FILTer:LPASs:FREQuency`` command.
        """
        return self._lpass


class OutputItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``OUTPut[n]`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``OUTPut[n]?`` query.
        - Using the ``.verify(value)`` method will send the ``OUTPut[n]?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.filter``: The ``OUTPut[n]:FILTer`` command tree.
        - ``.state``: The ``OUTPut[n]:STATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "OUTPut[n]") -> None:
        super().__init__(device, cmd_syntax)
        self._filter = OutputItemFilter(device, f"{self._cmd_syntax}:FILTer")
        self._state = OutputItemState(device, f"{self._cmd_syntax}:STATe")

    @property
    def filter(self) -> OutputItemFilter:
        """Return the ``OUTPut[n]:FILTer`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``OUTPut[n]:FILTer?`` query.
            - Using the ``.verify(value)`` method will send the ``OUTPut[n]:FILTer?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.lpass``: The ``OUTPut[n]:FILTer:LPASs`` command tree.
        """
        return self._filter

    @property
    def state(self) -> OutputItemState:
        """Return the ``OUTPut[n]:STATe`` command.

        **Description:**
            - This command and query sets or returns the output state of the arbitrary waveform
              generator. Setting the output state of a channel to ON will switch on its analog
              output signal and marker.

        **Usage:**
            - Using the ``.query()`` method will send the ``OUTPut[n]:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``OUTPut[n]:STATe?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``OUTPut[n]:STATe value`` command.

        **SCPI Syntax:**

        ::

            - OUTPut[n]:STATe <output_state>
            - OUTPut[n]:STATe?

        **Info:**
            - ``<output_state>`` ::=<Boolean>.
            - ``0`` sets the channel output to False (OFF).
            - ``1`` sets the channel output to True (ON).
        """
        return self._state



"""The test commands module.

These commands are used in the following models:
DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7KC, DSA70KC, DSA70KD, MSO5KB, MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - TEST <QString>
    - TEST:RESults:VERBose?
    - TEST:RESults?
    - TEST:STOP
    - TEST?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class TestStop(SCPICmdWriteNoArguments):
    """The ``TEST:STOP`` command.

    **Description:**
        - This command (no query form) causes test (or diagnostics) execution to terminate at the
          end of the next low-level test. This command is equivalent to selecting Instrument
          Diagnostics from the Utilities menu and then clicking Abort.

    **Usage:**
        - Using the ``.write()`` method will send the ``TEST:STOP`` command.

    **SCPI Syntax:**

    ::

        - TEST:STOP
    """


class TestResultsVerbose(SCPICmdRead):
    """The ``TEST:RESults:VERBose`` command.

    **Description:**
        - This query-only command returns a more explanatory message about the results of the last
          TEST execution than the ``TEST:RESULTS`` query. This command is equivalent to selecting
          Instrument Diagnostics from the Utilities menu and then clicking the Error Log button.

    **Usage:**
        - Using the ``.query()`` method will send the ``TEST:RESults:VERBose?`` query.
        - Using the ``.verify(value)`` method will send the ``TEST:RESults:VERBose?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - TEST:RESults:VERBose?
    """


class TestResults(SCPICmdRead):
    """The ``TEST:RESults`` command.

    **Description:**
        - This query-only command returns an abbreviated status about the results of the last TEST
          execution. This command is equivalent to selecting Instrument Diagnostics from the
          Utilities menu and then reviewing the Diagnostic Status.

    **Usage:**
        - Using the ``.query()`` method will send the ``TEST:RESults?`` query.
        - Using the ``.verify(value)`` method will send the ``TEST:RESults?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - TEST:RESults?

    Properties:
        - ``.verbose``: The ``TEST:RESults:VERBose`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._verbose = TestResultsVerbose(device, f"{self._cmd_syntax}:VERBose")

    @property
    def verbose(self) -> TestResultsVerbose:
        """Return the ``TEST:RESults:VERBose`` command.

        **Description:**
            - This query-only command returns a more explanatory message about the results of the
              last TEST execution than the ``TEST:RESULTS`` query. This command is equivalent to
              selecting Instrument Diagnostics from the Utilities menu and then clicking the Error
              Log button.

        **Usage:**
            - Using the ``.query()`` method will send the ``TEST:RESults:VERBose?`` query.
            - Using the ``.verify(value)`` method will send the ``TEST:RESults:VERBose?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - TEST:RESults:VERBose?
        """
        return self._verbose


class Test(SCPICmdWrite, SCPICmdRead):
    """The ``TEST`` command.

    **Description:**
        - This command provides the ability to select and execute an item at any level of the test
          hierarchy (Test, Area or Subsystem). The query returns the last command sent. This command
          is equivalent to selecting Instrument Diagnostics from the Utilities menu, choosing a test
          and then pressing Run.

    **Usage:**
        - Using the ``.query()`` method will send the ``TEST?`` query.
        - Using the ``.verify(value)`` method will send the ``TEST?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``TEST value`` command.

    **SCPI Syntax:**

    ::

        - TEST <QString>
        - TEST?

    **Info:**
        - ``<QString>`` sets the test ID, which ranges from 0 through 3 characters. If no test ID is
          specified, all available diagnostics are executed.

    Properties:
        - ``.results``: The ``TEST:RESults`` command.
        - ``.stop``: The ``TEST:STOP`` command.
    """

    _WRAP_ARG_WITH_QUOTES = True

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "TEST") -> None:
        super().__init__(device, cmd_syntax)
        self._results = TestResults(device, f"{self._cmd_syntax}:RESults")
        self._stop = TestStop(device, f"{self._cmd_syntax}:STOP")

    @property
    def results(self) -> TestResults:
        """Return the ``TEST:RESults`` command.

        **Description:**
            - This query-only command returns an abbreviated status about the results of the last
              TEST execution. This command is equivalent to selecting Instrument Diagnostics from
              the Utilities menu and then reviewing the Diagnostic Status.

        **Usage:**
            - Using the ``.query()`` method will send the ``TEST:RESults?`` query.
            - Using the ``.verify(value)`` method will send the ``TEST:RESults?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - TEST:RESults?

        Sub-properties:
            - ``.verbose``: The ``TEST:RESults:VERBose`` command.
        """
        return self._results

    @property
    def stop(self) -> TestStop:
        """Return the ``TEST:STOP`` command.

        **Description:**
            - This command (no query form) causes test (or diagnostics) execution to terminate at
              the end of the next low-level test. This command is equivalent to selecting Instrument
              Diagnostics from the Utilities menu and then clicking Abort.

        **Usage:**
            - Using the ``.write()`` method will send the ``TEST:STOP`` command.

        **SCPI Syntax:**

        ::

            - TEST:STOP
        """
        return self._stop



# pylint: disable=too-many-lines
"""The awgcontrol commands module.

These commands are used in the following models:
AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - AWGControl:ARSettings {0|1|ON|OFF}
    - AWGControl:CLOCk:DRATe <NR1>
    - AWGControl:CLOCk:DRATe?
    - AWGControl:CLOCk:PHASe:ADJust <NR1>
    - AWGControl:CLOCk:PHASe:ADJust?
    - AWGControl:CLOCk:SOURce {INTernal|EXTernal|EFIXed|EVARiable}
    - AWGControl:CLOCk:SOURce?
    - AWGControl:COMPile <filename>
    - AWGControl:CONFigure:CNUMber?
    - AWGControl:DLOading:ENABle {OFF|ON|0|1}
    - AWGControl:DLOading:ENABle?
    - AWGControl:DOUTput[n]:STATe {OFF|ON|0|1}
    - AWGControl:DOUTput[n]:STATe?
    - AWGControl:INTerleave:ADJustment:AMPLitude <NRf>
    - AWGControl:INTerleave:ADJustment:AMPLitude?
    - AWGControl:INTerleave:ADJustment:PHASe <NRf>
    - AWGControl:INTerleave:ADJustment:PHASe?
    - AWGControl:LSTate?
    - AWGControl:PJUMp:JSTRobe {0|1|OFF|ON}
    - AWGControl:PJUMp:JSTRobe?
    - AWGControl:PJUMp:SEDGe {FALLing|RISing}
    - AWGControl:PJUMp:SEDGe?
    - AWGControl:RMODe {CONTinuous|TRIGgered}
    - AWGControl:RMODe?
    - AWGControl:RSTate?
    - AWGControl:RUN:IMMediate
    - AWGControl:SNAMe?
    - AWGControl:SREStore <filepath>[,<msus>]
    - AWGControl:SSAVe <filepath>[,<msus>]
    - AWGControl:STOP:IMMediate
    - AWGControl:STReaming:ENABle {OFF|ON|0|1}
    - AWGControl:STReaming:ENABle?
    - AWGControl:STReaming:JEVent {ATRigger|BTRigger|T1}
    - AWGControl:STReaming:JEVent?
    - AWGControl:TIMer:INTerval:HZ <period>
    - AWGControl:TIMer:INTerval:HZ?
    - AWGControl:TIMer:INTerval:SEConds <period>
    - AWGControl:TIMer:INTerval:SEConds?
    - AWGControl:TIMer:RSTate?
    - AWGControl:TIMer:RUN
    - AWGControl:TIMer:SOPLay {OFF|ON|0|1}
    - AWGControl:TIMer:SOPLay?
    - AWGControl:TIMer:STOP
"""
from typing import Dict, Optional, TYPE_CHECKING

from .._helpers import (
    DefaultDictPassKeyToFactory,
    SCPICmdRead,
    SCPICmdWrite,
    SCPICmdWriteNoArguments,
    ValidatedDynamicNumberCmd,
)

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class AwgcontrolTimerStop(SCPICmdWriteNoArguments):
    """The ``AWGControl:TIMer:STOP`` command.

    **Description:**
        - This command stops the internal timer immediately.

    **Usage:**
        - Using the ``.write()`` method will send the ``AWGControl:TIMer:STOP`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:STOP
    """


class AwgcontrolTimerSoplay(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:TIMer:SOPLay`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of the timer to start and
          stop when waveform playout starts and stops.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer:SOPLay?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:SOPLay?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:TIMer:SOPLay value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:SOPLay {OFF|ON|0|1}
        - AWGControl:TIMer:SOPLay?
    """


class AwgcontrolTimerRun(SCPICmdWriteNoArguments):
    """The ``AWGControl:TIMer:RUN`` command.

    **Description:**
        - This command starts the internal timer immediately.

    **Usage:**
        - Using the ``.write()`` method will send the ``AWGControl:TIMer:RUN`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:RUN
    """


class AwgcontrolTimerRstate(SCPICmdRead):
    """The ``AWGControl:TIMer:RSTate`` command.

    **Description:**
        - This command returns the state of the internal timer (running or stopped). The timer can
          be stopped and started manually or automatically when the waveform playout starts and
          stops.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer:RSTate?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:RSTate?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:RSTate?
    """


class AwgcontrolTimerIntervalSeconds(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:TIMer:INTerval:SEConds`` command.

    **Description:**
        - This command sets or returns the internal timer interval period in seconds. The timer
          stops running on any change to the interval period or the instrument sample rate.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval:SEConds?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:INTerval:SEConds?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``AWGControl:TIMer:INTerval:SEConds value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:INTerval:SEConds <period>
        - AWGControl:TIMer:INTerval:SEConds?
    """


class AwgcontrolTimerIntervalHz(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:TIMer:INTerval:HZ`` command.

    **Description:**
        - This command sets or returns the internal timer interval period in Hertz. The timer stops
          running on any change to the interval period or the instrument sample rate.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval:HZ?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:INTerval:HZ?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:TIMer:INTerval:HZ value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:TIMer:INTerval:HZ <period>
        - AWGControl:TIMer:INTerval:HZ?
    """


class AwgcontrolTimerInterval(SCPICmdRead):
    """The ``AWGControl:TIMer:INTerval`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:INTerval?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.hz``: The ``AWGControl:TIMer:INTerval:HZ`` command.
        - ``.seconds``: The ``AWGControl:TIMer:INTerval:SEConds`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._hz = AwgcontrolTimerIntervalHz(device, f"{self._cmd_syntax}:HZ")
        self._seconds = AwgcontrolTimerIntervalSeconds(device, f"{self._cmd_syntax}:SEConds")

    @property
    def hz(self) -> AwgcontrolTimerIntervalHz:
        """Return the ``AWGControl:TIMer:INTerval:HZ`` command.

        **Description:**
            - This command sets or returns the internal timer interval period in Hertz. The timer
              stops running on any change to the interval period or the instrument sample rate.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval:HZ?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:INTerval:HZ?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``AWGControl:TIMer:INTerval:HZ value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:INTerval:HZ <period>
            - AWGControl:TIMer:INTerval:HZ?
        """
        return self._hz

    @property
    def seconds(self) -> AwgcontrolTimerIntervalSeconds:
        """Return the ``AWGControl:TIMer:INTerval:SEConds`` command.

        **Description:**
            - This command sets or returns the internal timer interval period in seconds. The timer
              stops running on any change to the interval period or the instrument sample rate.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval:SEConds?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``AWGControl:TIMer:INTerval:SEConds?`` query and raise an AssertionError if the
              returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``AWGControl:TIMer:INTerval:SEConds value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:INTerval:SEConds <period>
            - AWGControl:TIMer:INTerval:SEConds?
        """
        return self._seconds


class AwgcontrolTimer(SCPICmdRead):
    """The ``AWGControl:TIMer`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:TIMer?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.interval``: The ``AWGControl:TIMer:INTerval`` command tree.
        - ``.rstate``: The ``AWGControl:TIMer:RSTate`` command.
        - ``.run``: The ``AWGControl:TIMer:RUN`` command.
        - ``.soplay``: The ``AWGControl:TIMer:SOPLay`` command.
        - ``.stop``: The ``AWGControl:TIMer:STOP`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._interval = AwgcontrolTimerInterval(device, f"{self._cmd_syntax}:INTerval")
        self._rstate = AwgcontrolTimerRstate(device, f"{self._cmd_syntax}:RSTate")
        self._run = AwgcontrolTimerRun(device, f"{self._cmd_syntax}:RUN")
        self._soplay = AwgcontrolTimerSoplay(device, f"{self._cmd_syntax}:SOPLay")
        self._stop = AwgcontrolTimerStop(device, f"{self._cmd_syntax}:STOP")

    @property
    def interval(self) -> AwgcontrolTimerInterval:
        """Return the ``AWGControl:TIMer:INTerval`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer:INTerval?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:INTerval?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.hz``: The ``AWGControl:TIMer:INTerval:HZ`` command.
            - ``.seconds``: The ``AWGControl:TIMer:INTerval:SEConds`` command.
        """
        return self._interval

    @property
    def rstate(self) -> AwgcontrolTimerRstate:
        """Return the ``AWGControl:TIMer:RSTate`` command.

        **Description:**
            - This command returns the state of the internal timer (running or stopped). The timer
              can be stopped and started manually or automatically when the waveform playout starts
              and stops.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer:RSTate?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:RSTate?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:RSTate?
        """
        return self._rstate

    @property
    def run(self) -> AwgcontrolTimerRun:
        """Return the ``AWGControl:TIMer:RUN`` command.

        **Description:**
            - This command starts the internal timer immediately.

        **Usage:**
            - Using the ``.write()`` method will send the ``AWGControl:TIMer:RUN`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:RUN
        """
        return self._run

    @property
    def soplay(self) -> AwgcontrolTimerSoplay:
        """Return the ``AWGControl:TIMer:SOPLay`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of the timer to start and
              stop when waveform playout starts and stops.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer:SOPLay?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer:SOPLay?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:TIMer:SOPLay value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:SOPLay {OFF|ON|0|1}
            - AWGControl:TIMer:SOPLay?
        """
        return self._soplay

    @property
    def stop(self) -> AwgcontrolTimerStop:
        """Return the ``AWGControl:TIMer:STOP`` command.

        **Description:**
            - This command stops the internal timer immediately.

        **Usage:**
            - Using the ``.write()`` method will send the ``AWGControl:TIMer:STOP`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:TIMer:STOP
        """
        return self._stop


class AwgcontrolStreamingJevent(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:STReaming:JEVent`` command.

    **Description:**
        - This command sets or returns the jump event for Streaming ID.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:STReaming:JEVent?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming:JEVent?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:STReaming:JEVent value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:STReaming:JEVent {ATRigger|BTRigger|T1}
        - AWGControl:STReaming:JEVent?
    """


class AwgcontrolStreamingEnable(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:STReaming:ENABle`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of Streaming ID .

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:STReaming:ENABle?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming:ENABle?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:STReaming:ENABle value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:STReaming:ENABle {OFF|ON|0|1}
        - AWGControl:STReaming:ENABle?
    """


class AwgcontrolStreaming(SCPICmdRead):
    """The ``AWGControl:STReaming`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:STReaming?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.enable``: The ``AWGControl:STReaming:ENABle`` command.
        - ``.jevent``: The ``AWGControl:STReaming:JEVent`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._enable = AwgcontrolStreamingEnable(device, f"{self._cmd_syntax}:ENABle")
        self._jevent = AwgcontrolStreamingJevent(device, f"{self._cmd_syntax}:JEVent")

    @property
    def enable(self) -> AwgcontrolStreamingEnable:
        """Return the ``AWGControl:STReaming:ENABle`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of Streaming ID .

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:STReaming:ENABle?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming:ENABle?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:STReaming:ENABle value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:STReaming:ENABle {OFF|ON|0|1}
            - AWGControl:STReaming:ENABle?
        """
        return self._enable

    @property
    def jevent(self) -> AwgcontrolStreamingJevent:
        """Return the ``AWGControl:STReaming:JEVent`` command.

        **Description:**
            - This command sets or returns the jump event for Streaming ID.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:STReaming:JEVent?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming:JEVent?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:STReaming:JEVent value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:STReaming:JEVent {ATRigger|BTRigger|T1}
            - AWGControl:STReaming:JEVent?
        """
        return self._jevent


class AwgcontrolStopImmediate(SCPICmdWriteNoArguments):
    """The ``AWGControl:STOP:IMMediate`` command.

    **Description:**
        - This command stops the output of a waveform or a sequence.

    **Usage:**
        - Using the ``.write()`` method will send the ``AWGControl:STOP:IMMediate`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:STOP:IMMediate
    """


class AwgcontrolStop(SCPICmdRead):
    """The ``AWGControl:STOP`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:STOP?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:STOP?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.immediate``: The ``AWGControl:STOP:IMMediate`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._immediate = AwgcontrolStopImmediate(device, f"{self._cmd_syntax}:IMMediate")

    @property
    def immediate(self) -> AwgcontrolStopImmediate:
        """Return the ``AWGControl:STOP:IMMediate`` command.

        **Description:**
            - This command stops the output of a waveform or a sequence.

        **Usage:**
            - Using the ``.write()`` method will send the ``AWGControl:STOP:IMMediate`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:STOP:IMMediate
        """
        return self._immediate


class AwgcontrolSsave(SCPICmdWrite):
    """The ``AWGControl:SSAVe`` command.

    **Description:**
        - This command saves the AWG's setup with waveforms.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``AWGControl:SSAVe value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:SSAVe <filepath>[,<msus>]
    """


class AwgcontrolSrestore(SCPICmdWrite):
    """The ``AWGControl:SREStore`` command.

    **Description:**
        - This command opens a setup file into the AWG's setup memory.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``AWGControl:SREStore value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:SREStore <filepath>[,<msus>]
    """


class AwgcontrolSname(SCPICmdRead):
    """The ``AWGControl:SNAMe`` command.

    **Description:**
        - This command returns the AWG's most recently saved setup location. The response contains
          the full path for the file, including the disk drive letter (msus or, mass storage unit
          specifier).

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:SNAMe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:SNAMe?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - AWGControl:SNAMe?
    """


class AwgcontrolRunImmediate(SCPICmdWriteNoArguments):
    """The ``AWGControl:RUN:IMMediate`` command.

    **Description:**
        - This command initiates the output of a waveform or sequence. This is equivalent to pushing
          the play button on the front-panel or display. The AWG can be put in the run state only
          when waveforms or sequences are assigned to channels.

    **Usage:**
        - Using the ``.write()`` method will send the ``AWGControl:RUN:IMMediate`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:RUN:IMMediate
    """


class AwgcontrolRun(SCPICmdRead):
    """The ``AWGControl:RUN`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:RUN?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:RUN?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.immediate``: The ``AWGControl:RUN:IMMediate`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._immediate = AwgcontrolRunImmediate(device, f"{self._cmd_syntax}:IMMediate")

    @property
    def immediate(self) -> AwgcontrolRunImmediate:
        """Return the ``AWGControl:RUN:IMMediate`` command.

        **Description:**
            - This command initiates the output of a waveform or sequence. This is equivalent to
              pushing the play button on the front-panel or display. The AWG can be put in the run
              state only when waveforms or sequences are assigned to channels.

        **Usage:**
            - Using the ``.write()`` method will send the ``AWGControl:RUN:IMMediate`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:RUN:IMMediate
        """
        return self._immediate


class AwgcontrolRstate(SCPICmdRead):
    """The ``AWGControl:RSTate`` command.

    **Description:**
        - This command returns the run state of the AWG.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:RSTate?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:RSTate?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - AWGControl:RSTate?
    """


class AwgcontrolRmode(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:RMODe`` command.

    **Description:**
        - This command sets or returns the run mode of the AWG for Channel 1.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:RMODe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:RMODe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:RMODe value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:RMODe {CONTinuous|TRIGgered}
        - AWGControl:RMODe?

    **Info:**
        - ``CONTinuous`` sets the Run Mode to Continuous (not waiting for a trigger event).
        - ``TRIGgered`` sets the Run Mode to Triggered, waiting for a trigger event. One waveform
          play out cycle completes, then play out stops, waiting for the next trigger event.
        - ``*RST`` sets this to CONT.
    """


class AwgcontrolPjumpSedge(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:PJUMp:SEDGe`` command.

    **Description:**
        - This command sets or returns the active Strobe Edge to use for Pattern Jump when Pattern
          Jump is enabled for Sequencing.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:PJUMp:SEDGe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp:SEDGe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:PJUMp:SEDGe value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:PJUMp:SEDGe {FALLing|RISing}
        - AWGControl:PJUMp:SEDGe?

    **Info:**
        - ``FALLing`` sets the falling edge of the strobe signal to the active edge. 256 input
          patterns are available.
        - ``RISing`` sets the rising edge of the strobe signal to the active edge. 256 input
          patterns are available.
    """


class AwgcontrolPjumpJstrobe(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:PJUMp:JSTRobe`` command.

    **Description:**
        - This command sets or returns if the pattern jump is set (enabled or disabled) to always
          occur on the strobe signal. With this setting disabled, the pattern jump requires a strobe
          signal and a pattern address change to initiate a jump. With this setting enabled, the
          pattern jump disregards the pattern address change condition, causing the jump to always
          occur on the strobe signal.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:PJUMp:JSTRobe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp:JSTRobe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:PJUMp:JSTRobe value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:PJUMp:JSTRobe {0|1|OFF|ON}
        - AWGControl:PJUMp:JSTRobe?
    """


class AwgcontrolPjump(SCPICmdRead):
    """The ``AWGControl:PJUMp`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:PJUMp?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.jstrobe``: The ``AWGControl:PJUMp:JSTRobe`` command.
        - ``.sedge``: The ``AWGControl:PJUMp:SEDGe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._jstrobe = AwgcontrolPjumpJstrobe(device, f"{self._cmd_syntax}:JSTRobe")
        self._sedge = AwgcontrolPjumpSedge(device, f"{self._cmd_syntax}:SEDGe")

    @property
    def jstrobe(self) -> AwgcontrolPjumpJstrobe:
        """Return the ``AWGControl:PJUMp:JSTRobe`` command.

        **Description:**
            - This command sets or returns if the pattern jump is set (enabled or disabled) to
              always occur on the strobe signal. With this setting disabled, the pattern jump
              requires a strobe signal and a pattern address change to initiate a jump. With this
              setting enabled, the pattern jump disregards the pattern address change condition,
              causing the jump to always occur on the strobe signal.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:PJUMp:JSTRobe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp:JSTRobe?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:PJUMp:JSTRobe value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:PJUMp:JSTRobe {0|1|OFF|ON}
            - AWGControl:PJUMp:JSTRobe?
        """
        return self._jstrobe

    @property
    def sedge(self) -> AwgcontrolPjumpSedge:
        """Return the ``AWGControl:PJUMp:SEDGe`` command.

        **Description:**
            - This command sets or returns the active Strobe Edge to use for Pattern Jump when
              Pattern Jump is enabled for Sequencing.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:PJUMp:SEDGe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp:SEDGe?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:PJUMp:SEDGe value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:PJUMp:SEDGe {FALLing|RISing}
            - AWGControl:PJUMp:SEDGe?

        **Info:**
            - ``FALLing`` sets the falling edge of the strobe signal to the active edge. 256 input
              patterns are available.
            - ``RISing`` sets the rising edge of the strobe signal to the active edge. 256 input
              patterns are available.
        """
        return self._sedge


class AwgcontrolLstate(SCPICmdRead):
    """The ``AWGControl:LSTate`` command.

    **Description:**
        - This command returns the waveform loading state of the arbitrary waveform generator when
          Dynamic Loading is enabled.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:LSTate?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:LSTate?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - AWGControl:LSTate?
    """


class AwgcontrolInterleaveAdjustmentPhase(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:INTerleave:ADJustment:PHASe`` command.

    **Description:**
        - This command sets or returns the interleave adjustment phase. The phase adjustment is
          applied to both of the channel's interleave DACs.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:INTerleave:ADJustment:PHASe?``
          query.
        - Using the ``.verify(value)`` method will send the
          ``AWGControl:INTerleave:ADJustment:PHASe?`` query and raise an AssertionError if the
          returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``AWGControl:INTerleave:ADJustment:PHASe value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:INTerleave:ADJustment:PHASe <NRf>
        - AWGControl:INTerleave:ADJustment:PHASe?

    **Info:**
        - ``*RST`` sets this to 0 degrees.
    """


class AwgcontrolInterleaveAdjustmentAmplitude(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:INTerleave:ADJustment:AMPLitude`` command.

    **Description:**
        - This command sets or returns the interleave amplitude adjustment as a percentage of the
          analog output voltage. The percentage is applied to both of the channel's interleave DACs
          such that the analog output voltage is minimally affected. When the analog output is
          changed, this amplitude percentage is applied at the same time.

    **Usage:**
        - Using the ``.query()`` method will send the
          ``AWGControl:INTerleave:ADJustment:AMPLitude?`` query.
        - Using the ``.verify(value)`` method will send the
          ``AWGControl:INTerleave:ADJustment:AMPLitude?`` query and raise an AssertionError if the
          returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the
          ``AWGControl:INTerleave:ADJustment:AMPLitude value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:INTerleave:ADJustment:AMPLitude <NRf>
        - AWGControl:INTerleave:ADJustment:AMPLitude?

    **Info:**
        - ``*RST`` sets this to 0%.
    """


class AwgcontrolInterleaveAdjustment(SCPICmdRead):
    """The ``AWGControl:INTerleave:ADJustment`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:INTerleave:ADJustment?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:INTerleave:ADJustment?``
          query and raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.amplitude``: The ``AWGControl:INTerleave:ADJustment:AMPLitude`` command.
        - ``.phase``: The ``AWGControl:INTerleave:ADJustment:PHASe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._amplitude = AwgcontrolInterleaveAdjustmentAmplitude(
            device, f"{self._cmd_syntax}:AMPLitude"
        )
        self._phase = AwgcontrolInterleaveAdjustmentPhase(device, f"{self._cmd_syntax}:PHASe")

    @property
    def amplitude(self) -> AwgcontrolInterleaveAdjustmentAmplitude:
        """Return the ``AWGControl:INTerleave:ADJustment:AMPLitude`` command.

        **Description:**
            - This command sets or returns the interleave amplitude adjustment as a percentage of
              the analog output voltage. The percentage is applied to both of the channel's
              interleave DACs such that the analog output voltage is minimally affected. When the
              analog output is changed, this amplitude percentage is applied at the same time.

        **Usage:**
            - Using the ``.query()`` method will send the
              ``AWGControl:INTerleave:ADJustment:AMPLitude?`` query.
            - Using the ``.verify(value)`` method will send the
              ``AWGControl:INTerleave:ADJustment:AMPLitude?`` query and raise an AssertionError if
              the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``AWGControl:INTerleave:ADJustment:AMPLitude value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:INTerleave:ADJustment:AMPLitude <NRf>
            - AWGControl:INTerleave:ADJustment:AMPLitude?

        **Info:**
            - ``*RST`` sets this to 0%.
        """
        return self._amplitude

    @property
    def phase(self) -> AwgcontrolInterleaveAdjustmentPhase:
        """Return the ``AWGControl:INTerleave:ADJustment:PHASe`` command.

        **Description:**
            - This command sets or returns the interleave adjustment phase. The phase adjustment is
              applied to both of the channel's interleave DACs.

        **Usage:**
            - Using the ``.query()`` method will send the
              ``AWGControl:INTerleave:ADJustment:PHASe?`` query.
            - Using the ``.verify(value)`` method will send the
              ``AWGControl:INTerleave:ADJustment:PHASe?`` query and raise an AssertionError if the
              returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``AWGControl:INTerleave:ADJustment:PHASe value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:INTerleave:ADJustment:PHASe <NRf>
            - AWGControl:INTerleave:ADJustment:PHASe?

        **Info:**
            - ``*RST`` sets this to 0 degrees.
        """
        return self._phase


class AwgcontrolInterleave(SCPICmdRead):
    """The ``AWGControl:INTerleave`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:INTerleave?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:INTerleave?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.adjustment``: The ``AWGControl:INTerleave:ADJustment`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._adjustment = AwgcontrolInterleaveAdjustment(device, f"{self._cmd_syntax}:ADJustment")

    @property
    def adjustment(self) -> AwgcontrolInterleaveAdjustment:
        """Return the ``AWGControl:INTerleave:ADJustment`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:INTerleave:ADJustment?``
              query.
            - Using the ``.verify(value)`` method will send the
              ``AWGControl:INTerleave:ADJustment?`` query and raise an AssertionError if the
              returned value does not match ``value``.

        Sub-properties:
            - ``.amplitude``: The ``AWGControl:INTerleave:ADJustment:AMPLitude`` command.
            - ``.phase``: The ``AWGControl:INTerleave:ADJustment:PHASe`` command.
        """
        return self._adjustment


class AwgcontrolDoutputItemState(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:DOUTput[n]:STATe`` command.

    **Description:**
        - This command sets or returns the state of the Direct signal path output (enabled or
          disabled) for the specified channel.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:DOUTput[n]:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:DOUTput[n]:STATe?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:DOUTput[n]:STATe value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:DOUTput[n]:STATe {OFF|ON|0|1}
        - AWGControl:DOUTput[n]:STATe?
    """


class AwgcontrolDoutputItem(ValidatedDynamicNumberCmd, SCPICmdRead):
    """The ``AWGControl:DOUTput[n]`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:DOUTput[n]?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:DOUTput[n]?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.state``: The ``AWGControl:DOUTput[n]:STATe`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._state = AwgcontrolDoutputItemState(device, f"{self._cmd_syntax}:STATe")

    @property
    def state(self) -> AwgcontrolDoutputItemState:
        """Return the ``AWGControl:DOUTput[n]:STATe`` command.

        **Description:**
            - This command sets or returns the state of the Direct signal path output (enabled or
              disabled) for the specified channel.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:DOUTput[n]:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:DOUTput[n]:STATe?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:DOUTput[n]:STATe value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:DOUTput[n]:STATe {OFF|ON|0|1}
            - AWGControl:DOUTput[n]:STATe?
        """
        return self._state


class AwgcontrolDloadingEnable(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:DLOading:ENABle`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) to either allow or not allow
          dynamic loading of waveforms into a sequence while the sequence is playing.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:DLOading:ENABle?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:DLOading:ENABle?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:DLOading:ENABle value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:DLOading:ENABle {OFF|ON|0|1}
        - AWGControl:DLOading:ENABle?
    """


class AwgcontrolDloading(SCPICmdRead):
    """The ``AWGControl:DLOading`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:DLOading?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:DLOading?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.enable``: The ``AWGControl:DLOading:ENABle`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._enable = AwgcontrolDloadingEnable(device, f"{self._cmd_syntax}:ENABle")

    @property
    def enable(self) -> AwgcontrolDloadingEnable:
        """Return the ``AWGControl:DLOading:ENABle`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) to either allow or not
              allow dynamic loading of waveforms into a sequence while the sequence is playing.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:DLOading:ENABle?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:DLOading:ENABle?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:DLOading:ENABle value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:DLOading:ENABle {OFF|ON|0|1}
            - AWGControl:DLOading:ENABle?
        """
        return self._enable


class AwgcontrolConfigureCnumber(SCPICmdRead):
    """The ``AWGControl:CONFigure:CNUMber`` command.

    **Description:**
        - This command returns the number of channels available on the AWG.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CONFigure:CNUMber?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CONFigure:CNUMber?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - AWGControl:CONFigure:CNUMber?
    """


class AwgcontrolConfigure(SCPICmdRead):
    """The ``AWGControl:CONFigure`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CONFigure?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CONFigure?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.cnumber``: The ``AWGControl:CONFigure:CNUMber`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._cnumber = AwgcontrolConfigureCnumber(device, f"{self._cmd_syntax}:CNUMber")

    @property
    def cnumber(self) -> AwgcontrolConfigureCnumber:
        """Return the ``AWGControl:CONFigure:CNUMber`` command.

        **Description:**
            - This command returns the number of channels available on the AWG.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CONFigure:CNUMber?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CONFigure:CNUMber?``
              query and raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - AWGControl:CONFigure:CNUMber?
        """
        return self._cnumber


class AwgcontrolCompile(SCPICmdWrite):
    """The ``AWGControl:COMPile`` command.

    **Description:**
        - This command compiles an equation file and imports the waveforms (created by the equation
          file) into the arbitrary waveform generator.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``AWGControl:COMPile value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:COMPile <filename>
    """


class AwgcontrolClockSource(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:CLOCk:SOURce`` command.

    **Description:**
        - This command sets or returns the source of the clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CLOCk:SOURce?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:SOURce?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:CLOCk:SOURce value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:CLOCk:SOURce {INTernal|EXTernal|EFIXed|EVARiable}
        - AWGControl:CLOCk:SOURce?

    **Info:**
        - ``INTernal`` - clock signal is generated internally and the reference frequency is derived
          by the internal oscillator. EFIXed - clock is generated internally and the reference
          frequency is derived from a fixed 10 MHz reference supplied at the Reference In connector.
          EVARiable - clock is generated internally and the reference frequency is derived from a
          variable reference supplied at the Reference In connector. EXTernal - clock signal
          supplied by the Clock In connector and the reference frequency is derived from the
          internal precision oscillator.
        - ``*RST`` sets this to INT.
    """


class AwgcontrolClockPhaseAdjust(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:CLOCk:PHASe:ADJust`` command.

    **Description:**
        - This command sets or returns the internal clock phase adjustment of the AWG.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CLOCk:PHASe:ADJust?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:PHASe:ADJust?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:CLOCk:PHASe:ADJust value``
          command.

    **SCPI Syntax:**

    ::

        - AWGControl:CLOCk:PHASe:ADJust <NR1>
        - AWGControl:CLOCk:PHASe:ADJust?
    """


class AwgcontrolClockPhase(SCPICmdRead):
    """The ``AWGControl:CLOCk:PHASe`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CLOCk:PHASe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:PHASe?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.adjust``: The ``AWGControl:CLOCk:PHASe:ADJust`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._adjust = AwgcontrolClockPhaseAdjust(device, f"{self._cmd_syntax}:ADJust")

    @property
    def adjust(self) -> AwgcontrolClockPhaseAdjust:
        """Return the ``AWGControl:CLOCk:PHASe:ADJust`` command.

        **Description:**
            - This command sets or returns the internal clock phase adjustment of the AWG.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CLOCk:PHASe:ADJust?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:PHASe:ADJust?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``AWGControl:CLOCk:PHASe:ADJust value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:CLOCk:PHASe:ADJust <NR1>
            - AWGControl:CLOCk:PHASe:ADJust?
        """
        return self._adjust


class AwgcontrolClockDrate(SCPICmdWrite, SCPICmdRead):
    """The ``AWGControl:CLOCk:DRATe`` command.

    **Description:**
        - This command sets or returns the divider rate for the external clock.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CLOCk:DRATe?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:DRATe?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``AWGControl:CLOCk:DRATe value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:CLOCk:DRATe <NR1>
        - AWGControl:CLOCk:DRATe?

    **Info:**
        - ``*RST`` sets this to 1.
    """


class AwgcontrolClock(SCPICmdRead):
    """The ``AWGControl:CLOCk`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl:CLOCk?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.phase``: The ``AWGControl:CLOCk:PHASe`` command tree.
        - ``.drate``: The ``AWGControl:CLOCk:DRATe`` command.
        - ``.source``: The ``AWGControl:CLOCk:SOURce`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._phase = AwgcontrolClockPhase(device, f"{self._cmd_syntax}:PHASe")
        self._drate = AwgcontrolClockDrate(device, f"{self._cmd_syntax}:DRATe")
        self._source = AwgcontrolClockSource(device, f"{self._cmd_syntax}:SOURce")

    @property
    def phase(self) -> AwgcontrolClockPhase:
        """Return the ``AWGControl:CLOCk:PHASe`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CLOCk:PHASe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:PHASe?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.adjust``: The ``AWGControl:CLOCk:PHASe:ADJust`` command.
        """
        return self._phase

    @property
    def drate(self) -> AwgcontrolClockDrate:
        """Return the ``AWGControl:CLOCk:DRATe`` command.

        **Description:**
            - This command sets or returns the divider rate for the external clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CLOCk:DRATe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:DRATe?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:CLOCk:DRATe value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:CLOCk:DRATe <NR1>
            - AWGControl:CLOCk:DRATe?

        **Info:**
            - ``*RST`` sets this to 1.
        """
        return self._drate

    @property
    def source(self) -> AwgcontrolClockSource:
        """Return the ``AWGControl:CLOCk:SOURce`` command.

        **Description:**
            - This command sets or returns the source of the clock.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CLOCk:SOURce?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk:SOURce?`` query
              and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:CLOCk:SOURce value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:CLOCk:SOURce {INTernal|EXTernal|EFIXed|EVARiable}
            - AWGControl:CLOCk:SOURce?

        **Info:**
            - ``INTernal`` - clock signal is generated internally and the reference frequency is
              derived by the internal oscillator. EFIXed - clock is generated internally and the
              reference frequency is derived from a fixed 10 MHz reference supplied at the Reference
              In connector. EVARiable - clock is generated internally and the reference frequency is
              derived from a variable reference supplied at the Reference In connector. EXTernal -
              clock signal supplied by the Clock In connector and the reference frequency is derived
              from the internal precision oscillator.
            - ``*RST`` sets this to INT.
        """
        return self._source


class AwgcontrolArsettings(SCPICmdWrite):
    """The ``AWGControl:ARSettings`` command.

    **Description:**
        - This command sets or returns the state (enabled or disabled) of whether or not to apply
          the recommended settings of waveforms and sequences when they are assigned to a channel.
          When enabled, the system attempts to use the waveform's recommended settings (sample rate,
          amplitude, and offset) when the waveform is assigned to a channel. This includes waveforms
          within sequence tracks assigned to a channel. Recommended settings are defined as part the
          waveform properties and sequence properties.

    **Usage:**
        - Using the ``.write(value)`` method will send the ``AWGControl:ARSettings value`` command.

    **SCPI Syntax:**

    ::

        - AWGControl:ARSettings {0|1|ON|OFF}
    """


#  pylint: disable=too-many-instance-attributes
class Awgcontrol(SCPICmdRead):
    """The ``AWGControl`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``AWGControl?`` query.
        - Using the ``.verify(value)`` method will send the ``AWGControl?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.arsettings``: The ``AWGControl:ARSettings`` command.
        - ``.clock``: The ``AWGControl:CLOCk`` command tree.
        - ``.compile``: The ``AWGControl:COMPile`` command.
        - ``.configure``: The ``AWGControl:CONFigure`` command tree.
        - ``.dloading``: The ``AWGControl:DLOading`` command tree.
        - ``.doutput``: The ``AWGControl:DOUTput[n]`` command tree.
        - ``.interleave``: The ``AWGControl:INTerleave`` command tree.
        - ``.lstate``: The ``AWGControl:LSTate`` command.
        - ``.pjump``: The ``AWGControl:PJUMp`` command tree.
        - ``.rmode``: The ``AWGControl:RMODe`` command.
        - ``.rstate``: The ``AWGControl:RSTate`` command.
        - ``.run``: The ``AWGControl:RUN`` command tree.
        - ``.sname``: The ``AWGControl:SNAMe`` command.
        - ``.srestore``: The ``AWGControl:SREStore`` command.
        - ``.ssave``: The ``AWGControl:SSAVe`` command.
        - ``.stop``: The ``AWGControl:STOP`` command tree.
        - ``.streaming``: The ``AWGControl:STReaming`` command tree.
        - ``.timer``: The ``AWGControl:TIMer`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "AWGControl") -> None:
        super().__init__(device, cmd_syntax)
        self._arsettings = AwgcontrolArsettings(device, f"{self._cmd_syntax}:ARSettings")
        self._compile = AwgcontrolCompile(device, f"{self._cmd_syntax}:COMPile")
        self._configure = AwgcontrolConfigure(device, f"{self._cmd_syntax}:CONFigure")
        self._dloading = AwgcontrolDloading(device, f"{self._cmd_syntax}:DLOading")
        self._doutput: Dict[int, AwgcontrolDoutputItem] = DefaultDictPassKeyToFactory(
            lambda x: AwgcontrolDoutputItem(device, f"{self._cmd_syntax}:DOUTput{x}")
        )
        self._interleave = AwgcontrolInterleave(device, f"{self._cmd_syntax}:INTerleave")
        self._lstate = AwgcontrolLstate(device, f"{self._cmd_syntax}:LSTate")
        self._pjump = AwgcontrolPjump(device, f"{self._cmd_syntax}:PJUMp")
        self._rmode = AwgcontrolRmode(device, f"{self._cmd_syntax}:RMODe")
        self._rstate = AwgcontrolRstate(device, f"{self._cmd_syntax}:RSTate")
        self._run = AwgcontrolRun(device, f"{self._cmd_syntax}:RUN")
        self._sname = AwgcontrolSname(device, f"{self._cmd_syntax}:SNAMe")
        self._srestore = AwgcontrolSrestore(device, f"{self._cmd_syntax}:SREStore")
        self._ssave = AwgcontrolSsave(device, f"{self._cmd_syntax}:SSAVe")
        self._stop = AwgcontrolStop(device, f"{self._cmd_syntax}:STOP")
        self._streaming = AwgcontrolStreaming(device, f"{self._cmd_syntax}:STReaming")
        self._timer = AwgcontrolTimer(device, f"{self._cmd_syntax}:TIMer")
        self._clock = AwgcontrolClock(device, f"{self._cmd_syntax}:CLOCk")

    @property
    def arsettings(self) -> AwgcontrolArsettings:
        """Return the ``AWGControl:ARSettings`` command.

        **Description:**
            - This command sets or returns the state (enabled or disabled) of whether or not to
              apply the recommended settings of waveforms and sequences when they are assigned to a
              channel. When enabled, the system attempts to use the waveform's recommended settings
              (sample rate, amplitude, and offset) when the waveform is assigned to a channel. This
              includes waveforms within sequence tracks assigned to a channel. Recommended settings
              are defined as part the waveform properties and sequence properties.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``AWGControl:ARSettings value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:ARSettings {0|1|ON|OFF}
        """
        return self._arsettings

    @property
    def compile(self) -> AwgcontrolCompile:
        """Return the ``AWGControl:COMPile`` command.

        **Description:**
            - This command compiles an equation file and imports the waveforms (created by the
              equation file) into the arbitrary waveform generator.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``AWGControl:COMPile value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:COMPile <filename>
        """
        return self._compile

    @property
    def configure(self) -> AwgcontrolConfigure:
        """Return the ``AWGControl:CONFigure`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CONFigure?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CONFigure?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.cnumber``: The ``AWGControl:CONFigure:CNUMber`` command.
        """
        return self._configure

    @property
    def dloading(self) -> AwgcontrolDloading:
        """Return the ``AWGControl:DLOading`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:DLOading?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:DLOading?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.enable``: The ``AWGControl:DLOading:ENABle`` command.
        """
        return self._dloading

    @property
    def doutput(self) -> Dict[int, AwgcontrolDoutputItem]:
        """Return the ``AWGControl:DOUTput[n]`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:DOUTput[n]?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:DOUTput[n]?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.state``: The ``AWGControl:DOUTput[n]:STATe`` command.
        """
        return self._doutput

    @property
    def interleave(self) -> AwgcontrolInterleave:
        """Return the ``AWGControl:INTerleave`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:INTerleave?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:INTerleave?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.adjustment``: The ``AWGControl:INTerleave:ADJustment`` command tree.
        """
        return self._interleave

    @property
    def lstate(self) -> AwgcontrolLstate:
        """Return the ``AWGControl:LSTate`` command.

        **Description:**
            - This command returns the waveform loading state of the arbitrary waveform generator
              when Dynamic Loading is enabled.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:LSTate?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:LSTate?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - AWGControl:LSTate?
        """
        return self._lstate

    @property
    def pjump(self) -> AwgcontrolPjump:
        """Return the ``AWGControl:PJUMp`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:PJUMp?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:PJUMp?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.jstrobe``: The ``AWGControl:PJUMp:JSTRobe`` command.
            - ``.sedge``: The ``AWGControl:PJUMp:SEDGe`` command.
        """
        return self._pjump

    @property
    def rmode(self) -> AwgcontrolRmode:
        """Return the ``AWGControl:RMODe`` command.

        **Description:**
            - This command sets or returns the run mode of the AWG for Channel 1.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:RMODe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:RMODe?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``AWGControl:RMODe value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:RMODe {CONTinuous|TRIGgered}
            - AWGControl:RMODe?

        **Info:**
            - ``CONTinuous`` sets the Run Mode to Continuous (not waiting for a trigger event).
            - ``TRIGgered`` sets the Run Mode to Triggered, waiting for a trigger event. One
              waveform play out cycle completes, then play out stops, waiting for the next trigger
              event.
            - ``*RST`` sets this to CONT.
        """
        return self._rmode

    @property
    def rstate(self) -> AwgcontrolRstate:
        """Return the ``AWGControl:RSTate`` command.

        **Description:**
            - This command returns the run state of the AWG.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:RSTate?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:RSTate?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - AWGControl:RSTate?
        """
        return self._rstate

    @property
    def run(self) -> AwgcontrolRun:
        """Return the ``AWGControl:RUN`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:RUN?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:RUN?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.immediate``: The ``AWGControl:RUN:IMMediate`` command.
        """
        return self._run

    @property
    def sname(self) -> AwgcontrolSname:
        """Return the ``AWGControl:SNAMe`` command.

        **Description:**
            - This command returns the AWG's most recently saved setup location. The response
              contains the full path for the file, including the disk drive letter (msus or, mass
              storage unit specifier).

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:SNAMe?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:SNAMe?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - AWGControl:SNAMe?
        """
        return self._sname

    @property
    def srestore(self) -> AwgcontrolSrestore:
        """Return the ``AWGControl:SREStore`` command.

        **Description:**
            - This command opens a setup file into the AWG's setup memory.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``AWGControl:SREStore value``
              command.

        **SCPI Syntax:**

        ::

            - AWGControl:SREStore <filepath>[,<msus>]
        """
        return self._srestore

    @property
    def ssave(self) -> AwgcontrolSsave:
        """Return the ``AWGControl:SSAVe`` command.

        **Description:**
            - This command saves the AWG's setup with waveforms.

        **Usage:**
            - Using the ``.write(value)`` method will send the ``AWGControl:SSAVe value`` command.

        **SCPI Syntax:**

        ::

            - AWGControl:SSAVe <filepath>[,<msus>]
        """
        return self._ssave

    @property
    def stop(self) -> AwgcontrolStop:
        """Return the ``AWGControl:STOP`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:STOP?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:STOP?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.immediate``: The ``AWGControl:STOP:IMMediate`` command.
        """
        return self._stop

    @property
    def streaming(self) -> AwgcontrolStreaming:
        """Return the ``AWGControl:STReaming`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:STReaming?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:STReaming?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.enable``: The ``AWGControl:STReaming:ENABle`` command.
            - ``.jevent``: The ``AWGControl:STReaming:JEVent`` command.
        """
        return self._streaming

    @property
    def timer(self) -> AwgcontrolTimer:
        """Return the ``AWGControl:TIMer`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:TIMer?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:TIMer?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.interval``: The ``AWGControl:TIMer:INTerval`` command tree.
            - ``.rstate``: The ``AWGControl:TIMer:RSTate`` command.
            - ``.run``: The ``AWGControl:TIMer:RUN`` command.
            - ``.soplay``: The ``AWGControl:TIMer:SOPLay`` command.
            - ``.stop``: The ``AWGControl:TIMer:STOP`` command.
        """
        return self._timer

    @property
    def clock(self) -> AwgcontrolClock:
        """Return the ``AWGControl:CLOCk`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``AWGControl:CLOCk?`` query.
            - Using the ``.verify(value)`` method will send the ``AWGControl:CLOCk?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.phase``: The ``AWGControl:CLOCk:PHASe`` command tree.
            - ``.drate``: The ``AWGControl:CLOCk:DRATe`` command.
            - ``.source``: The ``AWGControl:CLOCk:SOURce`` command.
        """
        return self._clock



"""The hcopy commands module.

These commands are used in the following models:
AFG3K, AFG3KB, AFG3KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - HCOPy:SDUMp:IMMediate
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class HcopySdumpImmediate(SCPICmdWriteNoArguments):
    """The ``HCOPy:SDUMp:IMMediate`` command.

    **Description:**
        - This command copies a screen image and saves the image file to a USB memory. The default
          file name is TEK00nnn.BMP, where nnn is a consecutive number from 000 through 999. The
          image files are saved in a folder named 'TEK' in the USB memory.

    **Usage:**
        - Using the ``.write()`` method will send the ``HCOPy:SDUMp:IMMediate`` command.

    **SCPI Syntax:**

    ::

        - HCOPy:SDUMp:IMMediate
    """


class HcopySdump(SCPICmdRead):
    """The ``HCOPy:SDUMp`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HCOPy:SDUMp?`` query.
        - Using the ``.verify(value)`` method will send the ``HCOPy:SDUMp?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.immediate``: The ``HCOPy:SDUMp:IMMediate`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._immediate = HcopySdumpImmediate(device, f"{self._cmd_syntax}:IMMediate")

    @property
    def immediate(self) -> HcopySdumpImmediate:
        """Return the ``HCOPy:SDUMp:IMMediate`` command.

        **Description:**
            - This command copies a screen image and saves the image file to a USB memory. The
              default file name is TEK00nnn.BMP, where nnn is a consecutive number from 000 through
              999. The image files are saved in a folder named 'TEK' in the USB memory.

        **Usage:**
            - Using the ``.write()`` method will send the ``HCOPy:SDUMp:IMMediate`` command.

        **SCPI Syntax:**

        ::

            - HCOPy:SDUMp:IMMediate
        """
        return self._immediate


class Hcopy(SCPICmdRead):
    """The ``HCOPy`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``HCOPy?`` query.
        - Using the ``.verify(value)`` method will send the ``HCOPy?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.sdump``: The ``HCOPy:SDUMp`` command tree.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "HCOPy") -> None:
        super().__init__(device, cmd_syntax)
        self._sdump = HcopySdump(device, f"{self._cmd_syntax}:SDUMp")

    @property
    def sdump(self) -> HcopySdump:
        """Return the ``HCOPy:SDUMp`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``HCOPy:SDUMp?`` query.
            - Using the ``.verify(value)`` method will send the ``HCOPy:SDUMp?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.immediate``: The ``HCOPy:SDUMp:IMMediate`` command.
        """
        return self._sdump



"""The system commands module.

These commands are used in the following models:
AWG5K, AWG5KC, AWG7K, AWG7KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:

::

    - SYSTem:DATE <year>,<month>,<day>
    - SYSTem:DATE?
    - SYSTem:ERRor:NEXT?
    - SYSTem:KLOCk <state>
    - SYSTem:KLOCk?
    - SYSTem:TIME <hour>,<minute>,<second>
    - SYSTem:TIME?
    - SYSTem:VERSion?
"""
from typing import Optional, TYPE_CHECKING

from .._helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.drivers.pi.pi_device import PIDevice


class SystemVersion(SCPICmdRead):
    """The ``SYSTem:VERSion`` command.

    **Description:**
        - This query-only command returns the conformed SCPI version of the instrument.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:VERSion?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:VERSion?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - SYSTem:VERSion?
    """


class SystemTime(SCPICmdWrite, SCPICmdRead):
    """The ``SYSTem:TIME`` command.

    **Description:**
        - This command sets or returns the system time (hours, minutes and seconds). This command is
          equivalent to the time setting through the Windows Control Panel.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:TIME?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:TIME?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SYSTem:TIME value`` command.

    **SCPI Syntax:**

    ::

        - SYSTem:TIME <hour>,<minute>,<second>
        - SYSTem:TIME?
    """


class SystemKlock(SCPICmdWrite, SCPICmdRead):
    """The ``SYSTem:KLOCk`` command.

    **Description:**
        - This command locks or unlocks the keyboard and front panel of the arbitrary waveform
          generator.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:KLOCk?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:KLOCk?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SYSTem:KLOCk value`` command.

    **SCPI Syntax:**

    ::

        - SYSTem:KLOCk <state>
        - SYSTem:KLOCk?

    **Info:**
        - ``<state>`` ::=<Boolean>.
        - ``0`` indicates False. The front panel and keyboard are unlocked.
        - ``1`` indicates True. The front panel and keyboard are locked.
    """


class SystemErrorNext(SCPICmdRead):
    """The ``SYSTem:ERRor:NEXT`` command.

    **Description:**
        - This query-only command returns the contents of the Error/Event queue.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:ERRor:NEXT?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:ERRor:NEXT?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    **SCPI Syntax:**

    ::

        - SYSTem:ERRor:NEXT?
    """


class SystemErrorCmd(SCPICmdRead):
    """The ``SYSTem:ERRor`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:ERRor?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:ERRor?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.next``: The ``SYSTem:ERRor:NEXT`` command.
    """

    def __init__(self, device: Optional["PIDevice"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._next = SystemErrorNext(device, f"{self._cmd_syntax}:NEXT")

    @property
    def next(self) -> SystemErrorNext:
        """Return the ``SYSTem:ERRor:NEXT`` command.

        **Description:**
            - This query-only command returns the contents of the Error/Event queue.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:ERRor:NEXT?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:ERRor:NEXT?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - SYSTem:ERRor:NEXT?
        """
        return self._next


class SystemDate(SCPICmdWrite, SCPICmdRead):
    """The ``SYSTem:DATE`` command.

    **Description:**
        - This command and query sets or returns the system date. When the values are nonintegers,
          they are rounded off to nearest integral values.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem:DATE?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem:DATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SYSTem:DATE value`` command.

    **SCPI Syntax:**

    ::

        - SYSTem:DATE <year>,<month>,<day>
        - SYSTem:DATE?

    **Info:**
        - ``<year>`` ::=<NRf> (Four digit number).
        - ``<month>`` ::=<NRf> from 1 to 12.
        - ``<day>`` ::=<NRf> from 1 to 31.
    """


class System(SCPICmdRead):
    """The ``SYSTem`` command tree.

    **Usage:**
        - Using the ``.query()`` method will send the ``SYSTem?`` query.
        - Using the ``.verify(value)`` method will send the ``SYSTem?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.date``: The ``SYSTem:DATE`` command.
        - ``.error``: The ``SYSTem:ERRor`` command tree.
        - ``.klock``: The ``SYSTem:KLOCk`` command.
        - ``.time``: The ``SYSTem:TIME`` command.
        - ``.version``: The ``SYSTem:VERSion`` command.
    """

    def __init__(self, device: Optional["PIDevice"] = None, cmd_syntax: str = "SYSTem") -> None:
        super().__init__(device, cmd_syntax)
        self._date = SystemDate(device, f"{self._cmd_syntax}:DATE")
        self._error = SystemError(device, f"{self._cmd_syntax}:ERRor")
        self._klock = SystemKlock(device, f"{self._cmd_syntax}:KLOCk")
        self._time = SystemTime(device, f"{self._cmd_syntax}:TIME")
        self._version = SystemVersion(device, f"{self._cmd_syntax}:VERSion")

    @property
    def date(self) -> SystemDate:
        """Return the ``SYSTem:DATE`` command.

        **Description:**
            - This command and query sets or returns the system date. When the values are
              nonintegers, they are rounded off to nearest integral values.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:DATE?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:DATE?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SYSTem:DATE value`` command.

        **SCPI Syntax:**

        ::

            - SYSTem:DATE <year>,<month>,<day>
            - SYSTem:DATE?

        **Info:**
            - ``<year>`` ::=<NRf> (Four digit number).
            - ``<month>`` ::=<NRf> from 1 to 12.
            - ``<day>`` ::=<NRf> from 1 to 31.
        """
        return self._date

    @property
    def error(self) -> SystemError:
        """Return the ``SYSTem:ERRor`` command tree.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:ERRor?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:ERRor?`` query and raise an
              AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.next``: The ``SYSTem:ERRor:NEXT`` command.
        """
        return self._error

    @property
    def klock(self) -> SystemKlock:
        """Return the ``SYSTem:KLOCk`` command.

        **Description:**
            - This command locks or unlocks the keyboard and front panel of the arbitrary waveform
              generator.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:KLOCk?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:KLOCk?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SYSTem:KLOCk value`` command.

        **SCPI Syntax:**

        ::

            - SYSTem:KLOCk <state>
            - SYSTem:KLOCk?

        **Info:**
            - ``<state>`` ::=<Boolean>.
            - ``0`` indicates False. The front panel and keyboard are unlocked.
            - ``1`` indicates True. The front panel and keyboard are locked.
        """
        return self._klock

    @property
    def time(self) -> SystemTime:
        """Return the ``SYSTem:TIME`` command.

        **Description:**
            - This command sets or returns the system time (hours, minutes and seconds). This
              command is equivalent to the time setting through the Windows Control Panel.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:TIME?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:TIME?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SYSTem:TIME value`` command.

        **SCPI Syntax:**

        ::

            - SYSTem:TIME <hour>,<minute>,<second>
            - SYSTem:TIME?
        """
        return self._time

    @property
    def version(self) -> SystemVersion:
        """Return the ``SYSTem:VERSion`` command.

        **Description:**
            - This query-only command returns the conformed SCPI version of the instrument.

        **Usage:**
            - Using the ``.query()`` method will send the ``SYSTem:VERSion?`` query.
            - Using the ``.verify(value)`` method will send the ``SYSTem:VERSion?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        **SCPI Syntax:**

        ::

            - SYSTem:VERSion?
        """
        return self._version



"""Base Data Acquisition (DAQ) device driver module."""
import inspect

from abc import ABC

from tm_devices.drivers.device import family_base_class
from tm_devices.drivers.pi.tsp_device import TSPDevice
from tm_devices.helpers import DeviceTypes


@family_base_class
class DataAcquisitionSystem(TSPDevice, ABC):
    """Base Data Acquisition (DAQ) device driver."""

    _DEVICE_TYPE = DeviceTypes.DAQ.value

    ################################################################################################
    # Private Methods
    ################################################################################################
    def _reboot(self) -> None:
        """Perform the actual rebooting code.

        Raises:
            NotImplementedError: Indicates the current driver has not implemented this method.
        """
        # TODO: implement
        raise NotImplementedError(
            f"``.{inspect.currentframe().f_code.co_name}()``"  # pyright: ignore
            f" is not yet implemented for the {self.__class__.__name__} driver"
        )



"""AWG70KA device driver module."""
from tm_devices.commands import AWG70KAMixin
from tm_devices.drivers.pi.signal_sources.awgs.awg import AWG, AWGSourceDeviceConstants


class AWG70KA(AWG70KAMixin, AWG):
    """AWG70KA device driver."""

    _DEVICE_CONSTANTS = AWGSourceDeviceConstants(
        memory_page_size=1,
        memory_max_record_length=2000000000,
        memory_min_record_length=1,
    )

    ################################################################################################
    # Public Methods
    ################################################################################################
